@@ -13,10 +13,11 @@ def create_dbt_oracle_context(username: str) -> Generator[None, None, None]:
     yields nothing
     but sets and unsets environment variables referenced by dbt profile
     """
-    secrets = get_dbt_oracle_secrets_for(username)
-    os.environ.update(secrets)
+    config = get_dbt_oracle_secrets_for(username)
+    config |= {"ORA_PYTHON_DRIVER_TYPE": "thin"}
+    os.environ.update(config)
     yield
-    for k in secrets:
+    for k in config:
         os.environ.pop(k)
 #    #secrets = get_dbt_oracle_secrets_for(username)
 #    try:
@@ -34,8 +35,6 @@ def run_dbt(profiles_dir: str, project_dir: str) -> None:
     assuming profiles yaml file is located
     this should be done inside a dbt_oracle context
     """
-    profiles_dir = profiles_dir
-    project_dir = project_dir
     try:
         subprocess.run(
             ["dbt", "test", "--profiles-dir", profiles_dir, "--project-dir", project_dir],
