@@ -1,7 +1,7 @@
 "secrets api"
-from typing_extensions import Any
 import os
 import json
+from typing import Any
 from google.cloud import secretmanager as _secretmanager
 
 
@@ -15,7 +15,7 @@ def _get_knada_gke_secrets() -> dict[str, Any]:
 
 def get_oracle_secrets_for(username: str) -> dict[str, str]:
     """reads and returns oracle secrets from knada gke"""
-    
+
     secrets = _get_knada_gke_secrets()["ORACLE_ONPREM"][os.environ["ORACLE_ENV"]]
     username = username.upper()
     return {
